@@ -64,10 +64,3 @@ pub mod weather_data;
 pub mod weather_forecast;
 /// CLI App Options and implementation
 pub mod weather_opts;
-
-use anyhow::{format_err, Error};
-use log::error;
-use retry::{
-    delay::{jitter, Exponential},
-    retry,
-};
